Index: runtime/observatory/tests/service/step_over_await_test.dart |
diff --git a/runtime/observatory/tests/service/step_over_await_test.dart b/runtime/observatory/tests/service/step_over_await_test.dart |
index f1e8d7ceea177103e7c9e1735d031753fba5e12e..c00cc91b8498740cb7efd48e8f3d67c52bd4575d 100644 |
--- a/runtime/observatory/tests/service/step_over_await_test.dart |
+++ b/runtime/observatory/tests/service/step_over_await_test.dart |
@@ -16,7 +16,7 @@ import 'package:unittest/unittest.dart'; |
const int LINE_A = 22; |
const int LINE_B = 24; |
// This tests the asyncStepOver command. |
asyncFunction() async { |
debugger(); |
print('a'); // LINE_A |
@@ -38,7 +38,8 @@ var tests = [ |
(Isolate isolate) async { |
expect(M.isAtAsyncSuspension(isolate.pauseEvent), isTrue); |
}, |
- asyncStepOver, |
+ asyncNext, |
+ hasStoppedAtBreakpoint, |
stoppedAtLine(LINE_B), |
resumeIsolate, |
]; |
@@ -16,7 +16,7 @@ import 'package:unittest/unittest.dart'; |
const int LINE_A = 22; |
const int LINE_B = 24; |
-// This tests the asyncStepOver command. |
+// This tests the asyncNext command. |
asyncFunction() async { |
debugger(); |